@@ -295,9 +295,9 @@ sub write_version {
 
     my @gmt = gmtime(time);
 
-    printf($h_version "Mandriva Linux %s %s-%s-%s%s %s\n",
-        $distrib->getvalue(undef, 'version') || 'cooker',
-        $distrib->getvalue(undef, 'branch') || 'cooker',
+    printf($h_version "Mageia %s %s-%s-%s%s %s\n",
+        $distrib->getvalue(undef, 'version') || 'cauldron',
+        $distrib->getvalue(undef, 'branch') || 'cauldron',
         $distrib->getvalue(undef, 'arch') || 'noarch',
         $distrib->getvalue(undef, 'product'),
         $distrib->getvalue(undef, 'tag') ? '-' . $distrib->getvalue(undef, 'tag') : '',
