@@ -198,7 +198,7 @@ sub check_media_coherency {
     foreach my $media ($distrib->listmedia) {
 	-d $distrib->getfullpath($media, 'path') or $error += _report_err(
 	    $fhout,
-		'MISSING_MEDIADIR', "dir %s does't exist for media `%s'",
+		'MISSING_MEDIADIR', "dir %s doesn't exist for media `%s'",
 	    $distrib->getpath($media, 'path'),
 	    $media
 	);
